From e2450b72726f3d9d14c38a93d0ca9634dc1ac0a5 Mon Sep 17 00:00:00 2001
From: Akash Mehrotra <mehrotra.akash@gmail.com>
Date: Sat, 13 Aug 2011 19:18:17 +0530
Subject: [PATCH 09/13] move equalizer.xml to httprequests.lua
 Use a table to return equalizer band values

---
 modules/lua/libs/equalizer.c            |   34 ++++++++++--------
 share/Makefile.am                       |    1 -
 share/lua/http/requests/README.txt      |    1 +
 share/lua/http/requests/equalizer.xml   |   57 -------------------------------
 share/lua/intf/modules/httprequests.lua |   22 +++++++++++-
 5 files changed, 40 insertions(+), 75 deletions(-)
 delete mode 100644 share/lua/http/requests/equalizer.xml

diff --git a/modules/lua/libs/equalizer.c b/modules/lua/libs/equalizer.c
index e8fbf7d..ffd492b 100644
--- a/modules/lua/libs/equalizer.c
+++ b/modules/lua/libs/equalizer.c
@@ -132,17 +132,14 @@ Band 8: 14 kHz
 Band 9: 16 kHz
 *****************************************************************************/
 /*****************************************************************************
-* Get the equalizer level for the specified band
+* Return EQ level for all bands as a Table
 *****************************************************************************/
 static int vlclua_equalizer_get( lua_State *L )
 {
-    int bandid = luaL_checknumber( L, 1 );
-    if ( bandid < 0 || bandid > 9)
-        return 0;
+    int bands = 9;
     input_thread_t *p_input = vlclua_get_input_internal( L );
     if( !p_input )
         return 0;
-
     audio_output_t *p_aout = input_GetAout( p_input );
     vlc_object_release( p_input );
     if( !p_aout )
@@ -160,12 +157,26 @@ static int vlclua_equalizer_get( lua_State *L )
 
     char *psz_bands_origin, *psz_bands;
     psz_bands_origin = psz_bands = var_GetNonEmptyString( p_aout, "equalizer-bands" );
+    if( !psz_bands )
+    {
+        vlc_object_release( p_aout );
+        return 0;
+    }
     locale_t loc = newlocale (LC_NUMERIC_MASK, "C", NULL);
     locale_t oldloc = uselocale (loc);
-    while( bandid >= 0 )
+    int i = 0;
+    char *str;
+    lua_newtable( L );
+    while( bands >= 0 )
     {
         level = strtof( psz_bands, &psz_bands);
-        bandid--;
+        bands--; 
+        asprintf( &str , "%f" , level );
+        lua_pushstring( L, str );
+        free(str);
+        asprintf( &str , "band_%d",i++ );
+        lua_setfield( L , -2 , str );
+        free(str);
     }
     free( psz_bands_origin );
     if (loc != (locale_t)0)
@@ -173,15 +184,8 @@ static int vlclua_equalizer_get( lua_State *L )
         uselocale (oldloc);
         freelocale (loc);
     }
-
     vlc_object_release( p_aout );
-    if( bandid == -1 )
-    {
-        lua_pushnumber( L, level );
-        return 1;
-    }
-    else
-        return 0;
+    return 1;
 }
 
 
diff --git a/share/Makefile.am b/share/Makefile.am
index 03f0ff2..9886b5f 100644
--- a/share/Makefile.am
+++ b/share/Makefile.am
@@ -333,7 +333,6 @@ DIST_http_lua = \
 	lua/http/requests/playlist.xml \
 	lua/http/requests/README.txt \
 	lua/http/requests/playlist_jstree.xml \
-	lua/http/requests/equalizer.xml \
 	lua/http/requests/browse.xml \
 	lua/http/requests/vlm_cmd.xml \
 	lua/http/requests/status.xml \
diff --git a/share/lua/http/requests/README.txt b/share/lua/http/requests/README.txt
index e2f99e4..9417597 100644
--- a/share/lua/http/requests/README.txt
+++ b/share/lua/http/requests/README.txt
@@ -128,6 +128,7 @@ Band 0: 60 Hz, 1: 170 Hz, 2: 310 Hz, 3: 600 Hz, 4: 1 kHz,
 
 <Display the list of presets available for the equalizer
 
+=======
 playlist.xml:
 =============
 < get the full playlist tree
diff --git a/share/lua/http/requests/equalizer.xml b/share/lua/http/requests/equalizer.xml
deleted file mode 100644
index 0071a5d..0000000
--- a/share/lua/http/requests/equalizer.xml
+++ /dev/null
@@ -1,57 +0,0 @@
-<?xml version="1.0" encoding="utf-8" standalone="yes" ?<?vlcprint'>'?>
-<?vlc --[[
-vim:syntax=lua
-<!--  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - >
-<  equalizer.xml: VLC media player web interface
-< - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - >
-<  Copyright (C) 2011 the VideoLAN team
-<  $Id$
-<
-<  Authors: Akash Mehrotra < mehrotra <dot> akash <at> gmail <dot> com >
-<
-<  This program is free software; you can redistribute it and/or modify
-<  it under the terms of the GNU General Public License as published by
-<  the Free Software Foundation; either version 2 of the License, or
-<  (at your option) any later version.
-<
-<  This program is distributed in the hope that it will be useful,
-<  but WITHOUT ANY WARRANTY; without even the implied warranty of
-<  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-<  GNU General Public License for more details.
-<
-<  You should have received a copy of the GNU General Public License
-<  along with this program; if not, write to the Free Software
-<  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
-< - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->
-]]?>
-<?vlc
-
-require "httprequests"
-
-local command = _GET['command']
-local val = _GET['val']
-local band = _GET['band']
-
-function round(what, precision)
-if what then return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,precision) else return "" end
-end
-
-if command == "preamp" then vlc.equalizer.preampset(val)
-elseif command == "equalizer" then vlc.equalizer.equalizerset(band,val)
-elseif command == "enable" then
-  if val == '0' then vlc.equalizer.enable(false) 
-  elseif val == '1' then vlc.equalizer.enable(true)
-  end
-end
-freq = { 60 , 170 , 310 , 600 , 1000 , 3000 , 6000 , 12000 , 14000 , 16000 }
-?>
-<root>
-  <preamp><?vlc print(round(vlc.equalizer.preampget(),2)) ?></preamp>
-  <equalizer>
-    <?vlc for i = 0,9
-    do print("<band id='"..i.."' freqency = '"..freq[i+1].."'>"..round(vlc.equalizer.equalizerget(i),1).."</band>") end ?>
-  </equalizer>
-  <presets>
-    <?vlc httprequests.printTableAsXml(vlc.equalizer.presets(),1) ?>
-  </presets>
-</root>
diff --git a/share/lua/intf/modules/httprequests.lua b/share/lua/intf/modules/httprequests.lua
index 664ac1f..00e26d3 100644
--- a/share/lua/intf/modules/httprequests.lua
+++ b/share/lua/intf/modules/httprequests.lua
@@ -59,6 +59,9 @@ function strsplit(text, delimiter)
 	return list
 end
 
+function round(what, precision)
+if what then return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,precision) else return "" end
+end
 
 --main function to process commands sent with the request
 
@@ -69,6 +72,7 @@ processcommands = function ()
 	local id = tonumber(_GET['id'] or -1)
 	local val = _GET['val']
 	local options = _GET['option']
+	local band = _GET['band']
 	if type(options) ~= "table" then -- Deal with the 0 or 1 option case
 	  options = { options }
 	end
@@ -158,8 +162,14 @@ processcommands = function ()
 	  if vlc.object.vout() then
 	   vlc.var.set(vlc.object.vout(),"aspect-ratio",val)
 	  end
+	elseif command == "preamp" then 
+	  vlc.equalizer.preampset(val)
+	elseif command == "equalizer" then 
+	  vlc.equalizer.equalizerset(band,val)
+	elseif command == "enableeq" then
+	  if val == '0' then vlc.equalizer.enable(false) else vlc.equalizer.enable(true) end
 	end
-	
+
 	local input = nil
 	local command = nil
 	local id = nil
@@ -391,7 +401,14 @@ local aout = vlc.object.aout()
 	s.random=vlc.var.get(playlist,"random")
 	s.loop=vlc.var.get(playlist,"loop")
 	s["repeat"]=vlc.var.get(playlist,"repeat")
-	
+        s.equalizer={}
+		s.equalizer.preamp=round(vlc.equalizer.preampget(),2)
+		s.equalizer.bands=vlc.equalizer.equalizerget()
+	        if s.equalizer.bands ~= null then
+		        for k,i in pairs(s.equalizer.bands) do s.equalizer.bands[k]=round(i,2) end
+		        s.equalizer.presets=vlc.equalizer.presets()
+		end
+
 	if (includecategories and item) then
 		s.information={}
 		s.information.category={}
@@ -421,3 +438,4 @@ local aout = vlc.object.aout()
 
 	return s
 end
+
-- 
1.7.4.1

